@@ -13,7 +13,7 @@ namespace Rstats {
 
     NV pi () { return M_PI; }
 
-    IV is_perl_number(SV* sv_str) {
+    Rstats::Logical is_perl_number(SV* sv_str) {
       if (!SvOK(sv_str)) {
         return 0;
       }
@@ -28,28 +28,28 @@ namespace Rstats {
 
     SV* cross_product(SV* sv_values) {
       
-      IV values_length = Rstats::pl_av_len(sv_values);
-      SV* sv_idxs = Rstats::pl_new_av_ref();
-      for (IV i = 0; i < values_length; i++) {
+      Rstats::Integer values_length = Rstats::pl_av_len(sv_values);
+      SV* sv_idxs = Rstats::pl_new_avrv();
+      for (Rstats::Integer i = 0; i < values_length; i++) {
         Rstats::pl_av_push(sv_idxs, Rstats::pl_new_sv_iv(0)); 
       }
       
-      SV* sv_idx_idx = Rstats::pl_new_av_ref();
-      for (IV i = 0; i < values_length; i++) {
+      SV* sv_idx_idx = Rstats::pl_new_avrv();
+      for (Rstats::Integer i = 0; i < values_length; i++) {
         Rstats::pl_av_push(sv_idx_idx, Rstats::pl_new_sv_iv(i));
       }
       
-      SV* sv_x1 = Rstats::pl_new_av_ref();
-      for (IV i = 0; i < values_length; i++) {
+      SV* sv_x1 = Rstats::pl_new_avrv();
+      for (Rstats::Integer i = 0; i < values_length; i++) {
         SV* sv_value = Rstats::pl_av_fetch(sv_values, i);
         Rstats::pl_av_push(sv_x1, Rstats::pl_av_fetch(sv_value, 0));
       }
 
-      SV* sv_result = Rstats::pl_new_av_ref();
+      SV* sv_result = Rstats::pl_new_avrv();
       Rstats::pl_av_push(sv_result, Rstats::pl_av_copy(sv_x1));
-      IV end_loop = 0;
+      Rstats::Logical end_loop = 0;
       while (1) {
-        for (IV i = 0; i < values_length; i++) {
+        for (Rstats::Integer i = 0; i < values_length; i++) {
           
           if (SvIV(Rstats::pl_av_fetch(sv_idxs, i)) < Rstats::pl_av_len(Rstats::pl_av_fetch(sv_values, i)) - 1) {
             
@@ -80,21 +80,21 @@ namespace Rstats {
 
     SV* pos_to_index(SV* sv_pos, SV* sv_dim) {
       
-      SV* sv_index = Rstats::pl_new_av_ref();
-      IV pos = SvIV(sv_pos);
-      IV before_dim_product = 1;
-      for (IV i = 0; i < Rstats::pl_av_len(sv_dim); i++) {
+      SV* sv_index = Rstats::pl_new_avrv();
+      Rstats::Integer pos = SvIV(sv_pos);
+      Rstats::Integer before_dim_product = 1;
+      for (Rstats::Integer i = 0; i < Rstats::pl_av_len(sv_dim); i++) {
         before_dim_product *= SvIV(Rstats::pl_av_fetch(sv_dim, i));
       }
       
-      for (IV i = Rstats::pl_av_len(sv_dim) - 1; i >= 0; i--) {
-        IV dim_product = 1;
-        for (IV k = 0; k < i; k++) {
+      for (Rstats::Integer i = Rstats::pl_av_len(sv_dim) - 1; i >= 0; i--) {
+        Rstats::Integer dim_product = 1;
+        for (Rstats::Integer k = 0; k < i; k++) {
           dim_product *= SvIV(Rstats::pl_av_fetch(sv_dim, k));
         }
         
-        IV reminder = pos % before_dim_product;
-        IV quotient = (IV)(reminder / dim_product);
+        Rstats::Integer reminder = pos % before_dim_product;
+        Rstats::Integer quotient = (Rstats::Integer)(reminder / dim_product);
         
         Rstats::pl_av_unshift(sv_index, Rstats::pl_new_sv_iv(quotient + 1));
         before_dim_product = dim_product;
@@ -105,11 +105,11 @@ namespace Rstats {
 
     SV* index_to_pos(SV* sv_index, SV* sv_dim_values) {
       
-      IV pos = 0;
-      for (IV i = 0; i < Rstats::pl_av_len(sv_dim_values); i++) {
+      Rstats::Integer pos = 0;
+      for (Rstats::Integer i = 0; i < Rstats::pl_av_len(sv_dim_values); i++) {
         if (i > 0) {
-          IV tmp = 1;
-          for (IV k = 0; k < i; k++) {
+          Rstats::Integer tmp = 1;
+          for (Rstats::Integer k = 0; k < i; k++) {
             tmp *= SvIV(Rstats::pl_av_fetch(sv_dim_values, k));
           }
           pos += tmp * (SvIV(Rstats::pl_av_fetch(sv_index, i)) - 1);
@@ -139,7 +139,7 @@ namespace Rstats {
           Perl_reg_numbered_buff_fetch(aTHX_ COMPLEX_IMAGE_ONLY_RE, 1, sv_im_str);
           sv_im = Rstats::pl_new_sv_nv(SvNV(sv_im_str));
           
-          sv_ret = Rstats::pl_new_hv_ref();
+          sv_ret = Rstats::pl_new_hvrv();
           Rstats::pl_hv_store(sv_ret, "re", sv_re);
           Rstats::pl_hv_store(sv_ret, "im", sv_im);
         }
@@ -157,7 +157,7 @@ namespace Rstats {
             sv_im = Rstats::pl_new_sv_nv(0);
           }
 
-          sv_ret = Rstats::pl_new_hv_ref();
+          sv_ret = Rstats::pl_new_hvrv();
           Rstats::pl_hv_store(sv_ret, "re", sv_re);
           Rstats::pl_hv_store(sv_ret, "im", sv_im);
         }
@@ -200,7 +200,7 @@ namespace Rstats {
       else {
         SV* sv_na = Rstats::pl_new_sv_pv("NA");
         if (sv_cmp(sv_value, sv_na) == 0) {
-          sv_ret = Rstats::pl_to_perl_obj(Rstats::VectorFunc::new_na(), "Rstats::Vector");
+          sv_ret = Rstats::pl_new_sv_iv(1);
         }
         else {
           sv_ret = &PL_sv_undef;
@@ -217,7 +217,7 @@ namespace Rstats {
         sv_ret = &PL_sv_undef;
       }
       else {
-        IV ret = Rstats::pl_pregexec(sv_str, INTEGER_RE);
+        Rstats::Logical ret = Rstats::pl_pregexec(sv_str, INTEGER_RE);
         if (ret) {
           SV* match1 = Rstats::pl_new_sv_pv("");
           Perl_reg_numbered_buff_fetch(aTHX_ INTEGER_RE, 1, match1);
@@ -238,7 +238,7 @@ namespace Rstats {
         sv_ret =  &PL_sv_undef;
       }
       else {
-        IV ret = Rstats::pl_pregexec(sv_value, DOUBLE_RE);
+        Rstats::Logical ret = Rstats::pl_pregexec(sv_value, DOUBLE_RE);
         if (ret) {
           SV* match1 = Rstats::pl_new_sv_pv("");
           Perl_reg_numbered_buff_fetch(aTHX_ DOUBLE_RE, 1, match1);
