@@ -82,6 +82,11 @@ my @func_names = qw/
   atanh
   atan2
   c_
+  c_double
+  c_character
+  c_complex
+  c_integer
+  c_logical
   C_
   charmatch
   chartr
@@ -214,11 +219,6 @@ my @func_names = qw/
   multiply
   divide
   pow
-  new_character
-  new_complex
-  new_double
-  new_integer
-  new_logical
   negation
   dim
   Inf
@@ -233,8 +233,9 @@ my @func_names = qw/
   dim_as_array
   class
   type
+  get_type
   at
-  length_value
+  get_length
 /;
 
 sub new {
